@@ -8,8 +8,6 @@ def main():
     print("##########################")
     print("Calculador WISC 4. Versión español, Argentina")
     print("##########################")
-    here = os.path.dirname(os.path.realpath(__file__))
-    df = os.path.join(here, 'data', 'wisc_4_es_ar.json')
-    w = Wisc(definition_data=df)
+    w = Wisc(wisc_version=4, language='es', country='ar')
     e = Evaluacion(wisc=w)
     e.ask_directas_as_terminal()
\ No newline at end of file
